@@ -3,7 +3,7 @@ our $AUTHORITY = 'cpan:GENE';
 
 # ABSTRACT: A weighted graph implementation
 
-our $VERSION = '0.5601';
+our $VERSION = '0.57';
 
 use warnings;
 use strict;
@@ -138,7 +138,7 @@ sub get_attr {
 }
 
 
-sub span {
+sub vertex_span {
     my ($self, $attr) = @_;
 
     my $mass = {};
@@ -167,6 +167,37 @@ sub span {
 }
 
 
+sub edge_span {
+    my ($self, $attr) = @_;
+
+    my $mass = {};
+    for my $edge ( $self->edges ) {
+        $mass->{ $edge->[0] . '_' . $edge->[1] } = $self->get_attr($edge, $attr);
+    }
+
+    my ($smallest, $biggest);
+    for my $edge ( keys %$mass ) {
+        my $current = $mass->{$edge};
+        if ( !defined $smallest || $smallest > $current ) {
+            $smallest = $current;
+        }
+        if ( !defined $biggest || $biggest < $current ) {
+            $biggest = $current;
+        }
+    }
+
+    my ($lightest, $heaviest) = ([], []);
+    for my $edge ( sort keys %$mass ) {
+        my $arrayref = [ split /_/, $edge ];
+        push @$lightest, $arrayref if $mass->{$edge} == $smallest;
+        push @$heaviest, $arrayref if $mass->{$edge} == $biggest;
+    }
+
+    return $lightest, $heaviest;
+}
+
+
+
 sub path_attr {
     my ($self, $path, $attr) = @_;
 
@@ -195,7 +226,7 @@ Graph::Weighted - A weighted graph implementation
 
 =head1 VERSION
 
-version 0.5601
+version 0.57
 
 =head1 SYNOPSIS
 
@@ -219,11 +250,13 @@ version 0.5601
     }
  }
 
- my ($lightest, $heaviest) = $gw->span();
+ my ($lightest, $heaviest) = $gw->vertex_span();
+ ($lightest, $heaviest) = $gw->edge_span();
+
  my $weight = $gw->path_attr(\@vertices);
 
- my $gw = Graph::Weighted->new();
  my $attr = 'probability';
+ $gw = Graph::Weighted->new();
  $gw->populate(
     {
         0 => { 1 => 0.4, 3 => 0.6 }, # Vertex 0 with 2 edges of weight 1
@@ -299,13 +332,20 @@ If no value is found, zero is returned.
 
 Return the named attribute value for the vertex or edge.
 
-=head2 span()
+=head2 vertex_span()
 
- my ($lightest, $heaviest) = $gw->span();
- my ($lightest, $heaviest) = $gw->span($attr);
+ my ($lightest, $heaviest) = $gw->vertex_span();
+ my ($lightest, $heaviest) = $gw->vertex_span($attr);
 
 Return the span of lightest to heaviest vertices.
 
+=head2 edge_span()
+
+ my ($lightest, $heaviest) = $gw->edge_span();
+ my ($lightest, $heaviest) = $gw->edge_span($attr);
+
+Return the span of lightest to heaviest edges.
+
 =head2 path_attr()
 
  my $weight = $gw->path_attr(\@vertices);
